@@ -15,9 +15,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+"""
+Package for parsing ``Authentication-Results`` headers as defined in RFC 5451.
+Optional support for authentication methods defined in RFCs 5617, 6008, and 6212.
+"""
+
+__author__  = 'Julian Mehnle, Scott Kitterman'
+__email__   = 'scott@kitterman.com'
+__version__ = '0.402'
+
 def _test():
     import doctest
     import authres
+    doctest.testfile("tests")
     return doctest.testmod(authres)
 
 _test()
